@@ -1,7 +1,7 @@
 import json
-import requests
+# import requests
 
-from automon.log import Logging
+from automon.log.logger import Logging
 from automon.integrations.elasticsearch.client import ElasticsearchClient
 from automon.integrations.elasticsearch.config import ElasticsearchConfig
 
@@ -10,7 +10,7 @@ class Snapshot:
     def __init__(self, snapshot: dict):
         self._log = Logging(Snapshot.__name__, Logging.DEBUG)
 
-        self.snapshot = snapshot
+        self._snapshot = snapshot
         self.id = snapshot.get('id')
         self.status = snapshot.get('status')
         self.start_epoch = snapshot.get('start_epoch')
@@ -28,19 +28,21 @@ class Snapshot:
             self._log.warning(f'{other} != Snapshot')
             return NotImplemented
 
-        return self.snapshot == other.snapshot
+        return self._snapshot == other._snapshot
 
 
 class ElasticsearchSnapshotMonitor:
-    def __init__(self, endpoint: str, elasticsearch_repository: str, snapshots_prefix: str):
+    def __init__(self, elasticsearch_repository: str, snapshots_prefix: str = '',
+                 config: ElasticsearchConfig = ElasticsearchConfig()):
         self._log = Logging(ElasticsearchSnapshotMonitor.__name__, Logging.DEBUG)
 
-        self._config = ElasticsearchConfig(endpoint)
-        self._client = ElasticsearchClient(self._config)
+        self._config = config if config == ElasticsearchConfig else ElasticsearchConfig()
+        self._client = ElasticsearchClient(config=self._config)
+        self.connected = self._client.connected
 
         self._endpoint = self._client.config.es_hosts
-        self._repository = elasticsearch_repository
-        self._snapshots_prefix = snapshots_prefix
+        self.repository = elasticsearch_repository
+        self.snapshots_prefix = snapshots_prefix
 
         self.snapshots = []
         self.total_snapshots = None
@@ -49,15 +51,18 @@ class ElasticsearchSnapshotMonitor:
         self.error = None
 
     def _get_all_snapshots(self) -> bool:
-        if self._client.connected:
-            url = f'{self._endpoint}/_cat/snapshots/{self._repository}?format=json&pretty'
+        if self.connected:
+            for endpoint in self._endpoint:
+                url = f'{endpoint}/_cat/snapshots/{self.repository}?format=json'
+                # url = f'{endpoint}/_snapshot/{self.repository}?format=json'
 
-            self._log.info('Downloading snapshots list')
-            content = self._client.rest(url)
+                self._log.info('Downloading snapshots list')
+                request = self._client.rest(url)
+                content = request.text
 
-            if content:
-                snapshots = json.loads(content)
-                return self._process_snapshots(snapshots)
+                if request:
+                    snapshots = json.loads(content)
+                    return self._process_snapshots(snapshots)
 
         return False
 
@@ -76,7 +81,7 @@ class ElasticsearchSnapshotMonitor:
                 id = s.id
                 status = s.status
 
-                if self._snapshots_prefix in id:
+                if self.snapshots_prefix in id:
 
                     self.snapshots.append(s)
 
@@ -87,7 +92,7 @@ class ElasticsearchSnapshotMonitor:
 
             return True
 
-        except:
+        except Exception as _:
             self._log.error('Unable to get snapshots')
             self.error = SnapshotError(snapshots)
             return False
