@@ -10,11 +10,11 @@ class Scan:
         self.scan_date = scan['scan_date']
 
         try:
-            self._scans = result['plist']['array']['dict'] or []
+            self._scans = result['plist']['array']['dict']
             self.ssids = [Ssid(ssid) for ssid in self._scans]
         except Exception as e:
             self.ssids = []
-            log.debug(f'No ssids found, {" ".join(scan["cmd"])}')
+            log.error(f'Scan failed to parse, {" ".join(scan["cmd"])}')
 
     def __repr__(self):
         return f'{[[x.ssid for x in self.ssids]]}'
@@ -30,19 +30,25 @@ class Ssid:
 
         self.mac = ssid['string'][0]
         self.ssid = ssid['string'][1]
-
-        for key in ssid['dict']:
-            if 'string' in key.keys() and 'data' in key.keys() and 'dict' in key.keys():
-                if isinstance(key['string'], list):
-                    self.device_info = key['string']
-            else:
-                self.device_info = ''
+        self.device_info = self._device_info(ssid) or ''
 
         log.debug(f'Found SSID: {self.ssid} ({self.mac}) {self.device_info}')
 
+    def _device_info(self, ssid):
+        if 'dict' in ssid:
+            for key in ssid['dict']:
+                if isinstance(key, dict):
+                    if 'string' in key.keys() and 'data' in key.keys() and 'dict' in key.keys():
+                        if isinstance(key['string'], list):
+                            return key['string']
+
     def __repr__(self):
-        return f'{self.ssid} {self.device_info}'
+        return f'{self.ssid} {self.mac} {self.device_info}'
 
     def __eq__(self, other):
         if isinstance(other, Ssid):
             return self.mac, self.ssid == other.mac, other.ssid
+
+    def __lt__(self, other):
+        if isinstance(other, Ssid):
+            return self.ssid == other.ssid
